@@ -392,17 +392,19 @@ int main(int argc, char *argv[]) {
   g_signal_connect(G_OBJECT(window), "destroy", 
 		   G_CALLBACK(on_window_destroy), NULL);
 
+  GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
+  gtk_container_add(GTK_CONTAINER(window), vbox);
+
   /* create map widget */
   GtkWidget *map = map_new();
 
-  /* attach menu to main window, this may create a new container */
-  /* for the main view */
-  GtkWidget *container = menu_create(window, map);
+  /* attach menu to main window */
+  menu_create(vbox, map);
 
   g_signal_connect(G_OBJECT(map), "destroy", 
 		   G_CALLBACK(on_map_destroy), NULL);
 
-  gtk_container_add(GTK_CONTAINER(container), map);
+  gtk_box_pack_start_defaults(GTK_BOX(vbox), map);
 
   track_restore(map);
 
